/*
 * LibSKK, a tiny Library to emulate SKK (Simple Kana Kanji Conversion)
 * 
 * Copyright (C) 2002 Motonobu Ichimura <famao@kondara.org>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
 * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */

/* $Id: skkconv_jisx0201_kana_private.h,v 1.4 2002/11/09 16:56:49 famao Exp $ */

/* vi:set ts=4 sw=4: */


#ifndef SKKCONV_JISX0201_KANA_PRIVATE_H
#define SKKCONV_JISX0201_KANA_PRIVATE_H
#include <glib.h>
#include <skkconv_jisx0201_kana.h>

jisx0201_rule_list jisx0201_list[] = {
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"Î",	""	},
	{	"",	""	},
	{	"Ď",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"ʎ",	""	},
	{	"ʎ",	""	},
	{	"",	""	},
	{	"ˎ",	""	},
	{	"ˎ",	""	},
	{	"",	""	},
	{	"̎",	""	},
	{	"̎",	""	},
	{	"",	""	},
	{	"͎",	""	},
	{	"͎",	""	},
	{	"",	""	},
	{	"Ύ",	""	},
	{	"Ύ",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
	{	"",	""	},
};

#endif /* SKKCONV_JISX0201_KANA_PRIVATE_H */
